Learn R Programming

rAverage (version 0.4-10)

pargen: Generating random parameters for averaging responses

Description

Generates a random set of parameters that follows an averaging rule.

Usage

pargen(lev, s.range = c(0,20), w.range = exp(c(-5,5)),
        I0 = FALSE, t.par = FALSE, digits = 2)

Arguments

lev
Numeric vector. Number of levels of each factor.
s.range
Numeric vector. Range of variability of the s-parameters.
w.range
Numeric vector. Range of variability of the w-parameters.
I0
Logical. If set to FALSE, parameter s0 and w0 are set to zero. If set TRUE initial parameters are free to be estimated.
t.par
Specifies if the weight parameters should be the 't' instead the 'w'.
digits
Numeric. Decimal rounding of the parameters.

Value

  • Vector contaning the random-generated parameters in the order s0,w0,s(k,i),w(k,i).

See Also

datgen, rav, rav.indices, rAverage-package

Examples

Run this code
# Generating random parameters for a 3x4 design:
param <- pargen(lev = c(3,4))

Run the code above in your browser using DataLab